%define enable_bootlogd_service 0

Summary: Programs which control basic system processes
Name: sysvinit-legacy
Version: 2.87
# (cg) Remember to update systemd when you bump release here.
Release: %mkrel 17
License: GPLv2+
Group: System/Configuration/Boot and Init
Source: https://alioth.debian.org/frs/download.php/3060/sysvinit-%{version}.tar.gz
Source1: bootlogd
Source2: stop-bootlogd
URL: https://alioth.debian.org/projects/pkg-sysvinit/
Patch1: sysvinit-2.78-man.patch
Patch4: sysvinit-2.86-autofsck.patch
Patch5: sysvinit-2.86-loginshell.patch
Patch8: sysvinit-2.86-inittab.patch
Patch10: sysvinit-2.87-pidof.patch
Patch13: sysvinit-2.86-single.patch
Patch16: sysvinit-2.86-quiet.patch
Patch23: sysvinit-2.86-pidof-man.patch
Patch24: sysvinit-2.87-sulogin.patch
Patch25: sysvinit-2.87-wide.patch
Patch26: sysvinit-2.87-ipv6.patch
# Add -m option to pidof to omit processes that match existing omitted pids (#632321)
Patch27: sysvinit-2.87-omit.patch

# Mandriva patches
Patch100: sysvinit-2.86-shutdown.patch
Patch101: sysvinit-2.87-libcrypt.patch
Patch104: sysvinit-2.85-walltty.patch
Patch105: sysvinit-disable-respawn-more-quickly.patch
# do not try to take over console tty for rc.sysinit, it conflicts with speedboot (Mdv bug #58488)
Patch106: sysvinit-2.87-speedboot-ioctl.patch

# Debian patches
Patch200: 50_bootlogd_devsubdir.patch
Patch201: 54_bootlogd_findptyfail.patch
Patch202: 55_bootlogd_flush.patch
Patch203: sysvinit-2.87dsf-fix-ioctl.patch
BuildRequires: glibc-static-devel
Requires: pam >= 0.66-5
Requires(post): coreutils
Requires: sysvinit-tools = %{version}-%{release}
Obsoletes: SysVinit < 2.86-6
Provides: SysVinit = %{version}-%{release}
Provides: sysvinit = %{version}-%{release}

%description
The sysvinit package contains a group of processes that control
the very basic functions of your system. sysvinit includes the init
program, the first program started by the Linux kernel when the
system boots. Init then controls the startup, running, and shutdown
of all other programs.

%package tools
Summary: Tools used for process and utmp management
Group: System/Configuration/Boot and Init
Conflicts: sysvinit < 2.87-2
Requires(pre): coreutils
%rename sysvinit-tools

%description tools
The sysvinit-tools package contains various tools used for process
management.


%package -n drakx-installer-sysvinit
Summary: Init program used by the installer
Group: System/Configuration/Boot and Init
Conflicts: sysvinit < 2.87-2
Requires(pre): coreutils

%description -n drakx-installer-sysvinit
This package contains the init program used by the installer rescue.


%prep
%setup -q -n sysvinit-%{version}dsf
# We use a shell, not sulogin. Other random man fixes go here (such as #192804)
%patch1 -p1 -b .manpatch
# Unlink /.autofsck on shutdown -f
%patch4 -p1 -b .autofsck
# Invoke single-user shell as a login shell (#105653)
%patch5 -p1 -b .loginshell
# Adjust examples in inittab(5) to more accurately reflect RH/Fedora
# usage (#173572)
%patch8 -p1 -b .inittabdocs
# Fix various things in pidof - pidof /x/y matching /z/y, pidof -x
# for scripts, etc.
%patch10 -p1 -b .pidof
# Fix single user mode (#176348)
%patch13 -p1 -b .single
# Be less verbose when booted with 'quiet'
%patch16 -p1 -b .quiet
# Document some of the behavior of pidof. (#201317)
%patch23 -p1 -b .pidof
# get_default_context_with_level returns 0 on success (#568530)
%patch24 -p1 -b .sulogin
# Add wide output names with -w (#550333)
%patch25 -p1 -b .wide
# Change accepted ipv6 addresses (#573346)
%patch26 -p1 -b .ipv6
# Support -m option for pidof (#632321)
%patch27 -p1 -b .omit

%patch100 -p1 -b .shutdown
%patch101 -p1 -b .libcrypt
%patch104 -p1 -b .wall
%patch105 -p1 -b .disable-respawn-more-quickly
%patch106 -p1 -b .speedboot-ioctl

%patch200 -p1 -b .bootlogd_devsubdir
%patch201 -p1 -b .bootlogd_findptyfail
%patch202 -p1 -b .bootlogd_flush
%patch203 -p1 -b .ioctl

%build
%make CFLAGS="%{optflags} -D_GNU_SOURCE" LDFLAGS="%{ldflags}" -C src

%install
rm -rf %{buildroot}
for I in bin sbin usr/{bin,include} %{_mandir}/man{1,3,5,8} etc var/run dev; do
	mkdir -p %{buildroot}/$I
done

make -C src ROOT=%{buildroot} MANDIR=%{_mandir} STRIP=/bin/true \
	BIN_OWNER=`id -nu` BIN_GROUP=`id -ng` install

# If this already exists, just do nothing (the ||: part)
mknod --mode=0600 %{buildroot}/dev/initctl p ||:
ln -snf killall5 %{buildroot}/sbin/pidof

chmod 755 %{buildroot}/usr/bin/utmpdump

mkdir -p %{buildroot}%{_sysconfdir}/rc.d/init.d/
install -m755 %{SOURCE1} %{SOURCE2} %{buildroot}%{_sysconfdir}/rc.d/init.d/

%if !%enable_bootlogd_service
sed -i -e 's/\(chkconfig\:\s\+\)2345/\1-/g' %{buildroot}%{_sysconfdir}/rc.d/init.d/bootlogd %{buildroot}%{_sysconfdir}/rc.d/init.d/stop-bootlogd
%endif

mkdir -p  %{buildroot}%{_sysconfdir}/sysconfig
cat << EOF > %{buildroot}%{_sysconfdir}/sysconfig/bootlogd
BOOTLOGD_ENABLED=no
EOF

mkdir -p %buildroot%_libdir/drakx-installer-sysvinit
ln %buildroot/sbin/init %buildroot%_libdir/drakx-installer-sysvinit


# Remove unpackaged file(s)
rm -rf	%{buildroot}/usr/include

%post
%_post_service bootlogd
%_post_service stop-bootlogd

[ ! -p /dev/initctl ] && rm -f /dev/initctl && mknod --mode=0600 /dev/initctl p || :
[ -e /var/run/initrunlvl ] && ln -s ../var/run/initrunlvl /etc/initrunlvl || :
[ -x /sbin/telinit -a -p /dev/initctl -a -f /proc/1/exe -a -d /proc/1/root ] && /sbin/telinit u || :
exit 0

%preun
%_preun_service bootlogd
%_preun_service stop-bootlogd

%clean
rm -rf %{buildroot}

%files
%doc doc/Propaganda doc/Install
%doc doc/sysvinit-*.lsm contrib/start-stop-daemon.* 
/sbin/bootlogd
/sbin/halt
/sbin/init
/sbin/poweroff
/sbin/reboot
/sbin/runlevel
/sbin/shutdown
/sbin/telinit
%{_mandir}/man5/*
%{_mandir}/man8/halt*
%{_mandir}/man8/init*
%{_mandir}/man8/poweroff*
%{_mandir}/man8/reboot*
%{_mandir}/man8/runlevel*
%{_mandir}/man8/shutdown*
%{_mandir}/man8/telinit*
%{_mandir}/man8/bootlogd*
%ghost /dev/initctl

%{_sysconfdir}/rc.d/init.d/*bootlogd
%config(noreplace) %{_sysconfdir}/sysconfig/bootlogd

%files tools
%doc doc/Changelog COPYRIGHT
/bin/mountpoint
/bin/pidof
%{_bindir}/last
%{_bindir}/lastb
%{_bindir}/mesg
%{_bindir}/utmpdump
%attr(2555,root,tty)  /usr/bin/wall
/sbin/pidof
/sbin/killall5
/sbin/sulogin
%{_mandir}/man1/*
%{_mandir}/man8/killall5*
%{_mandir}/man8/pidof*
%{_mandir}/man8/sulogin*


%files -n drakx-installer-sysvinit
%_libdir/drakx-installer-sysvinit


%changelog

* Sun Apr 08 2012 colin <colin> 2.87-17.mga2
+ Revision: 229703
- Fix disabling of bootlogd since sysvinit scripts were fixed

* Sun Apr 08 2012 colin <colin> 2.87-16.mga2
+ Revision: 229678
- Fix uninstall service name (mga#5247)

* Sun Apr 01 2012 colin <colin> 2.87-15.mga2
+ Revision: 227735
- Drop rsyslog sysvinit config (it's now the default again) mga#4131

* Wed Mar 07 2012 tmb <tmb> 2.87-14.mga2
+ Revision: 221219
- provide sysvinit
- clean spec
- rename spec
- rename to sysvinit-legacy to help migration to systemd

* Thu Feb 16 2012 colin <colin> 2.87-13.mga2
+ Revision: 209738
- Bump release
- Enable rsyslog kernel logging with sysvinit

* Sun Jan 15 2012 tv <tv> 2.87-12.mga2
+ Revision: 196432
- create drakx-installer-sysvinit sub package

* Thu Dec 29 2011 tmb <tmb> 2.87-11.mga2
+ Revision: 188793
- fix chkconfig setup
- make sure coreutils are installed before sysvinit-tools (mga #3917)

* Wed Apr 27 2011 rtp <rtp> 2.87-10.mga1
+ Revision: 92151
- fix build failure due to missing error code define.

* Tue Jan 04 2011 tmb <tmb> 2.87-9.mga1
+ Revision: 133
- imported package sysvinit

